==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/sk.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendár",
    "Todos" : "Úlohy",
    "Personal" : "Osobné",
    "{actor} created calendar {calendar}" : "[actor] vytvoril kalendár [calendar]",
    "You created calendar {calendar}" : "Vytvorili ste kalendár [calendar]",
    "{actor} deleted calendar {calendar}" : "[actor] zmazal kalendár [calendar]",
    "You deleted calendar {calendar}" : "Zmazali ste kalendár [calendar]",
    "{actor} updated calendar {calendar}" : "[actor] upravil kalendár [calendar]",
    "You updated calendar {calendar}" : "Upravili ste kalendár [calendar]",
    "{actor} shared calendar {calendar} with you" : "{actor} vám sprístupnil kalendár {calendar}",
    "You shared calendar {calendar} with {user}" : "Sprístupnili ste kalendár {calendar} s {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} sprístupnil kalendár {calendar} s {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} vám prestal sprístupňovať kalendár {calendar}",
    "You unshared calendar {calendar} from {user}" : "Prestali ste sprístupňovať kalendár {calendar} od používateľa {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zrušil zdieľanie kalendára {calendar} s používateľom {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zrušil zdieľanie kalendára {calendar} so sebou samým",
    "You shared calendar {calendar} with group {group}" : "Sprístupnili ste kalendár {calendar} so skupinou {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} vyzdieľal kalendár {calendar} so skupinou {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušili ste zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}  zrušil zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvoril udalosť {event} v kalendári {calendar}",
    "You created event {event} in calendar {calendar}" : "Vytvorili ste udalosť [event] v kalendári [calendar]",
    "{actor} deleted event {event} from calendar {calendar}" : "[actor] zmazal udalosť [event] z kalendára [calendar]",
    "You deleted event {event} from calendar {calendar}" : "Zmazali ste udalosť [event] z kalendára [calendar]",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}  aktualizoval udalosť {event} v kalendári {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizovali ste udalosť {event} v kalendári {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} vytvoril úlohu {todo} v {calendar}",
    "You created todo {todo} in list {calendar}" : "Vytvorili ste úlohu {todo} v {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} zmazal úlohu {todo} z {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Zmazali ste úlohu {todo} z {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} upravil úlohu {todo} v {calendar}",
    "You updated todo {todo} in list {calendar}" : "Upravili ste úlohu {todo} v {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} vyriešil úlohu {todo} v {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vyriešili ste úlohu {todo} v {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otvoril úlohu {todo} v {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Otvorili ste znovu úlohu {todo} v {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>kalendár</strong> bol upravený",
    "A calendar <strong>event</strong> was modified" : "<strong>Udalosť</strong> v kalendári bola upravená",
    "A calendar <strong>todo</strong> was modified" : "<>",
    "Contact birthdays" : "Narodeniny kontaktu",
    "Invitation canceled" : "Pozvánka bola zrušená",
    "Hello %s," : "Ahoj %s,",
    "The meeting »%s« with %s was canceled." : "Stretnutie »%s« s %s bolo zrušené.",
    "Invitation updated" : "Pozvánka bola aktualizovaná",
    "The meeting »%s« with %s was updated." : "Stretnutie »%s« s %s bolo aktualizované.",
    "%s invited you to »%s«" : "%s vám poslal pozvánku na »%s«",
    "When:" : "Kedy:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "Link:" : "Odkaz:",
    "Contacts" : "Kontakty",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdialená adresa: %s",
    "Request ID: %s" : "ID požiadavky: %s",
    "CalDAV server" : "Server CalDAV",
    "Send invitations to attendees" : "Odoslanie pozvánok účastníkom",
    "Please make sure to properly set up the email settings above." : "Uistite sa, že máte správne nastavené vyššie uvedené nastavenia e-mailu.",
    "Automatically generate a birthday calendar" : "Automaticky generovať narodeninový kalendár",
    "Birthday calendars will be generated by a background job." : "Narodeninové kalendáre budú generované úlohou na pozadí."
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dav/l10n/sk.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Kalendár",
    "Todos" : "Úlohy",
    "Personal" : "Osobné",
    "{actor} created calendar {calendar}" : "[actor] vytvoril kalendár [calendar]",
    "You created calendar {calendar}" : "Vytvorili ste kalendár [calendar]",
    "{actor} deleted calendar {calendar}" : "[actor] zmazal kalendár [calendar]",
    "You deleted calendar {calendar}" : "Zmazali ste kalendár [calendar]",
    "{actor} updated calendar {calendar}" : "[actor] upravil kalendár [calendar]",
    "You updated calendar {calendar}" : "Upravili ste kalendár [calendar]",
    "You shared calendar {calendar} as public link" : "Sprístupnili ste kalendár {calendar}  ako verejný odkaz",
    "You removed public link for calendar {calendar}" : "Odstránili ste verejný odkaz pre kalendár {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} vám sprístupnil kalendár {calendar}",
    "You shared calendar {calendar} with {user}" : "Sprístupnili ste kalendár {calendar} s {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} sprístupnil kalendár {calendar} s {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} vám prestal sprístupňovať kalendár {calendar}",
    "You unshared calendar {calendar} from {user}" : "Prestali ste sprístupňovať kalendár {calendar} od používateľa {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} zrušil zdieľanie kalendára {calendar} s používateľom {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} zrušil zdieľanie kalendára {calendar} so sebou samým",
    "You shared calendar {calendar} with group {group}" : "Sprístupnili ste kalendár {calendar} so skupinou {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} vyzdieľal kalendár {calendar} so skupinou {group}",
    "You unshared calendar {calendar} from group {group}" : "Zrušili ste zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}  zrušil zdieľanie kalendára {calendar} so skupinou {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} vytvoril udalosť {event} v kalendári {calendar}",
    "You created event {event} in calendar {calendar}" : "Vytvorili ste udalosť [event] v kalendári [calendar]",
    "{actor} deleted event {event} from calendar {calendar}" : "[actor] zmazal udalosť [event] z kalendára [calendar]",
    "You deleted event {event} from calendar {calendar}" : "Zmazali ste udalosť [event] z kalendára [calendar]",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}  aktualizoval udalosť {event} v kalendári {calendar}",
    "You updated event {event} in calendar {calendar}" : "Aktualizovali ste udalosť {event} v kalendári {calendar}",
    "{actor} created todo {todo} in list {calendar}" : "{actor} vytvoril úlohu {todo} v {calendar}",
    "You created todo {todo} in list {calendar}" : "Vytvorili ste úlohu {todo} v {calendar}",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor} zmazal úlohu {todo} z {calendar}",
    "You deleted todo {todo} from list {calendar}" : "Zmazali ste úlohu {todo} z {calendar}",
    "{actor} updated todo {todo} in list {calendar}" : "{actor} upravil úlohu {todo} v {calendar}",
    "You updated todo {todo} in list {calendar}" : "Upravili ste úlohu {todo} v {calendar}",
    "{actor} solved todo {todo} in list {calendar}" : "{actor} vyriešil úlohu {todo} v {calendar}",
    "You solved todo {todo} in list {calendar}" : "Vyriešili ste úlohu {todo} v {calendar}",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor} znovu otvoril úlohu {todo} v {calendar}",
    "You reopened todo {todo} in list {calendar}" : "Otvorili ste znovu úlohu {todo} v {calendar}",
    "A <strong>calendar</strong> was modified" : "<strong>kalendár</strong> bol upravený",
    "A calendar <strong>event</strong> was modified" : "<strong>Udalosť</strong> v kalendári bola upravená",
    "A calendar <strong>todo</strong> was modified" : "<strong>Pripomienka</strong> v kalendári bola upravená",
    "Contact birthdays" : "Narodeniny kontaktu",
    "Invitation canceled" : "Pozvánka bola zrušená",
    "Hello %s," : "Ahoj %s,",
    "The meeting »%s« with %s was canceled." : "Stretnutie »%s« s %s bolo zrušené.",
    "Invitation updated" : "Pozvánka bola aktualizovaná",
    "The meeting »%s« with %s was updated." : "Stretnutie »%s« s %s bolo aktualizované.",
    "%s invited you to »%s«" : "%s vám poslal pozvánku na »%s«",
    "When:" : "Kedy:",
    "Where:" : "Kde:",
    "Description:" : "Popis:",
    "Link:" : "Odkaz:",
    "Contacts" : "Kontakty",
    "WebDAV" : "WebDAV",
    "Technical details" : "Technické podrobnosti",
    "Remote Address: %s" : "Vzdialená adresa: %s",
    "Request ID: %s" : "ID požiadavky: %s",
    "CalDAV server" : "Server CalDAV",
    "Send invitations to attendees" : "Odoslanie pozvánok účastníkom",
    "Please make sure to properly set up the email settings above." : "Uistite sa, že máte správne nastavené vyššie uvedené nastavenia e-mailu.",
    "Automatically generate a birthday calendar" : "Automaticky generovať narodeninový kalendár",
    "Birthday calendars will be generated by a background job." : "Narodeninové kalendáre budú generované úlohou na pozadí.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Preto nebudú dostupné hneď po povolení, ale zobrazia sa po určitom čase"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
